DropPolicy enum

Defines the behavior when the network buffer reaches its maximum capacity.

Inheritance
Available extensions

Values

discardOldest → const DropPolicy

Discard the oldest entries in the buffer to make room for new ones.

discardNewest → const DropPolicy

Discard the incoming entries until the buffer has space.

block → const DropPolicy

Pause logging until the buffer has space (blocking the application).

CAUTION: This can lead to performance issues if the network is down.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DropPolicy>
A constant List of the values in this enum, in order of their declaration.